# Zipline Extensions for QuantRocket
This package provides extensions and adapters for using the algorithmic backtesting library [Zipline](https://github.com/quantopian/zipline) with [QuantRocket](https://www.quantrocket.com).

For installation and usage documentation, please visit: https://www.quantrocket.com/docs/

## License

This package is distributed under the Apache 2.0 License. See the LICENSE file in the release for details.
